function [residual, g1, g2, g3] = NK_CGG02_impinf4_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 22, 1);

%
% Model equations
%

lhs =y(1);
rhs =y(1)-1/params(1)*(y(6)-y(5)-y(4));
residual(1)= lhs-rhs;
residual(2) = y(4);
lhs =y(2);
rhs =1/params(7)*((1+params(8))*y(9)-params(5)*y(14));
residual(3)= lhs-rhs;
lhs =y(1);
rhs =y(3)-y(2);
residual(4)= lhs-rhs;
lhs =y(5);
rhs =y(5)*params(2)+y(1)*params(3)+y(8);
residual(5)= lhs-rhs;
lhs =y(6);
rhs =y(6)*params(13)+(1-params(13))*(y(4)+y(11)+params(15)*(y(5)-y(11))+y(1)*params(16))+y(10);
residual(6)= lhs-rhs;
lhs =y(7);
rhs =y(6)-y(5);
residual(7)= lhs-rhs;
lhs =y(8);
rhs =y(8)*params(11)+x(1);
residual(8)= lhs-rhs;
lhs =y(9);
rhs =y(9)*params(12)+x(2);
residual(9)= lhs-rhs;
lhs =y(11);
rhs =(1-params(17))*params(18)+y(11)*params(17)+x(4);
residual(10)= lhs-rhs;
lhs =y(10);
rhs =y(10)*params(14)+x(3);
residual(11)= lhs-rhs;
lhs =y(12);
rhs =y(12)-1/params(21)*(y(17)-y(16)-y(15));
residual(12)= lhs-rhs;
residual(13) = y(15);
lhs =y(13);
rhs =1/params(27)*((1+params(28))*y(20)-y(3)*params(25));
residual(14)= lhs-rhs;
lhs =y(12);
rhs =y(14)-y(13);
residual(15)= lhs-rhs;
lhs =y(16);
rhs =y(16)*params(22)+y(12)*params(23)+y(19);
residual(16)= lhs-rhs;
lhs =y(17);
rhs =y(17)*params(32)+(1-params(32))*(y(15)+y(22)+params(34)*(y(16)-y(22))+y(12)*params(35))+y(21);
residual(17)= lhs-rhs;
lhs =y(18);
rhs =y(17)-y(16);
residual(18)= lhs-rhs;
lhs =y(19);
rhs =y(19)*params(30)+x(5);
residual(19)= lhs-rhs;
lhs =y(20);
rhs =y(20)*params(31)+x(6);
residual(20)= lhs-rhs;
lhs =y(22);
rhs =(1-params(36))*params(37)+y(22)*params(36)+x(8);
residual(21)= lhs-rhs;
lhs =y(21);
rhs =y(21)*params(33)+x(7);
residual(22)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(22, 22);

  %
  % Jacobian matrix
  %

  g1(1,4)=(-(1/params(1)));
  g1(1,5)=(-(1/params(1)));
  g1(1,6)=1/params(1);
  g1(2,4)=1;
  g1(3,2)=1;
  g1(3,9)=(-(1/params(7)*(1+params(8))));
  g1(3,14)=(-(1/params(7)*(-params(5))));
  g1(4,1)=1;
  g1(4,2)=1;
  g1(4,3)=(-1);
  g1(5,1)=(-params(3));
  g1(5,5)=1-params(2);
  g1(5,8)=(-1);
  g1(6,1)=(-((1-params(13))*params(16)));
  g1(6,4)=(-(1-params(13)));
  g1(6,5)=(-((1-params(13))*params(15)));
  g1(6,6)=1-params(13);
  g1(6,10)=(-1);
  g1(6,11)=(-((1-params(13))*(1-params(15))));
  g1(7,5)=1;
  g1(7,6)=(-1);
  g1(7,7)=1;
  g1(8,8)=1-params(11);
  g1(9,9)=1-params(12);
  g1(10,11)=1-params(17);
  g1(11,10)=1-params(14);
  g1(12,15)=(-(1/params(21)));
  g1(12,16)=(-(1/params(21)));
  g1(12,17)=1/params(21);
  g1(13,15)=1;
  g1(14,3)=(-(1/params(27)*(-params(25))));
  g1(14,13)=1;
  g1(14,20)=(-(1/params(27)*(1+params(28))));
  g1(15,12)=1;
  g1(15,13)=1;
  g1(15,14)=(-1);
  g1(16,12)=(-params(23));
  g1(16,16)=1-params(22);
  g1(16,19)=(-1);
  g1(17,12)=(-((1-params(32))*params(35)));
  g1(17,15)=(-(1-params(32)));
  g1(17,16)=(-((1-params(32))*params(34)));
  g1(17,17)=1-params(32);
  g1(17,21)=(-1);
  g1(17,22)=(-((1-params(32))*(1-params(34))));
  g1(18,16)=1;
  g1(18,17)=(-1);
  g1(18,18)=1;
  g1(19,19)=1-params(30);
  g1(20,20)=1-params(31);
  g1(21,22)=1-params(36);
  g1(22,21)=1-params(33);
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],22,484);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],22,10648);
end
end
end
end
