% A replication file for "Monetary Policy Surprises and Exchange Rate
% Behavior" by Gurkaynak, Kara, Kisacikoglu and Lee.

% This m file conducts structural estimation using GMM.

clear;
clc;
close all;

global oo_ M_ options_;

%% Load target moments

% run moments.m; 
load target_moments.mat;
num_moments = size(target_moments,1); % number of moments

%% Parameters

% 1. Fixed parameters

% Common to both countries
gamma = 0.5;

% US
rhou_infl = 0;
rhou_r = 0; 
infltargbar = 0;
c2 = 0.99; 
c4 = 0.99; 

% EA
rhou_inflstar = 0;
rhou_rstar = 0;
infltargstarbar = 0;
c2star = 0.99; 
c4star = 0.99;

param_fixed = [gamma rhou_infl rhou_r infltargbar c2 c4 ...
    rhou_inflstar rhou_rstar infltargstarbar c2star c4star];

% 2. Estimated parameters

% US
beta = 0.999;
sigma = 3;
phi = 2.5;
theta = 0.5;
rhoa = 0.9;
rhor = 0.8; 
phipi = 1.5;
phiy = 0.5;
rhoinfltarg = 0.95;

std_infl = 0.005;
std_a = 0.0005;
std_r = 0.0025;
std_infltarg = 0.0025;

% EA
betastar = 0.999;
sigmastar = 3;
phistar = 2.5;
thetastar = 0.75;
rhoastar = 0.9;
rhorstar = 0.7; 
phipistar = 1.5;
phiystar = 0.5;
rhoinfltargstar = 0.95;

std_inflstar = 0.005;
std_astar = 0.0005;
std_rstar = 0.0025;
std_infltargstar = 0.0025;

param_estimated_init = [beta sigma phi theta rhoa rhor phipi phiy rhoinfltarg ...
    betastar sigmastar phistar thetastar rhoastar rhorstar phipistar phiystar rhoinfltargstar ...
    std_infl std_a std_r std_infltarg ...
    std_inflstar std_astar std_rstar std_infltargstar];
    
%% Estimate

impinf = 1; % 1 if there is imperfect information
h = @(x) model_cgg(x,param_fixed,eye(num_moments),target_moments,impinf);

tic;

% 1. patternsearch

options = optimoptions('patternsearch');
options = optimoptions(options,'MaxFunEvals',5000,'MaxIter',5000);
options = optimoptions(options,'TolFun',1e-8,'TolX',1e-8);
options = optimoptions(options,'Display','iter');

[xgmm1,fval1,exitflag1] = patternsearch(h,param_estimated_init,[],[],[],[],[],[],[],options);

% 2. csminwel (optional; requires Chris Sim's csminwel package)

% [fval2,xgmm2] = csminwel(h,xgmm1,0.001*eye(size(xgmm1,1)),[],1e-8,500);

% 3. fminsearch

options = optimset('fminsearch');
options = optimset(options,'MaxFunEvals',30000,'MaxIter',30000);
options = optimset(options,'TolFun',1e-10,'TolX',1e-10);
options = optimset(options,'Display','iter');

[xgmm3,fval3,exitflag3] = fminsearch(h,xgmm1,options); 
[obj,model_moments] = h(xgmm3);

toc;

% save result_impinf_rr_infl_r_infltarg obj model_moments xgmm3;
% save result_impinf_ytilde_rr_infl_r obj model_moments xgmm3;

%% Table

format long;
disp('-----')
disp('                                   Select Moments');
labels = {'SD of Int_US';'SD of Int_EA';'SD of RGDP_US'; 'SD of RGDP_EA'; 'SD of Pi_US'; 'SD of Pi_EA'};
Model = model_moments(1:6);
Actual = target_moments(1:6);
T = table(Model,Actual,'RowNames',labels);
disp(T)