function [obj,modelmoments]=model_cgg(q,param_fixed,weightingmat,actualmoments,impinf)

global oo_ M_ options_;

%% Parameters

beta = q(1);
sigma = q(2);
phi = q(3);
theta = q(4);
rhoa = q(5);
rhor = q(6);
phipi = q(7);
phiy = q(8);
rhoinfltarg = q(9);
betastar = q(10);
sigmastar = q(11);
phistar = q(12);
thetastar = q(13);
rhoastar = q(14);
rhorstar = q(15); 
phipistar = q(16);
phiystar = q(17);
rhoinfltargstar = q(18);
std_infl = q(19);
std_a = q(20);
std_r = q(21);
std_infltarg = q(22);
std_inflstar = q(23);
std_astar = q(24);
std_rstar = q(25);
std_infltargstar = q(26);

if beta<0.98 || beta>=1 || sigma<0.15 || sigma>=5 || phi<0.2 || phi>=5 || theta<0 || theta>1 || ...
        rhoa<0 || rhoa>=1 || rhor<0 || rhor>=1 || phipi<0 || phipi>2.5 || phiy<0 || phiy>1.5 || phiy>=phipi || rhoinfltarg<0 || rhoinfltarg>=1 || ...
        betastar<0.98 || betastar>=1 || sigmastar<0.15 || sigmastar>=5 || phistar<0.2 || phistar>=5 || thetastar<0 || thetastar>=1 || ...
        rhoastar<0 || rhoastar>=1 || rhorstar<0 || rhorstar>=1 || phipistar<0 || phipistar>2.5 || phiystar<0 || phiystar>1.5 || phiystar>=phipistar || rhoinfltargstar<0 || rhoinfltargstar>=1 || ...
        std_infl<=0 || std_a<=0 || std_r<=0 || std_infltarg<=0 || ...
        std_inflstar<=0 || std_astar<=0 || std_rstar<=0 || std_infltargstar<=0
    obj = 1000000000000;
    return;
end

gamma = param_fixed(1);
rhou_infl = param_fixed(2);
rhou_r = param_fixed(3); 
infltargbar = param_fixed(4);
c2 = param_fixed(5); 
c4 = param_fixed(6);
rhou_inflstar = param_fixed(7);
rhou_rstar = param_fixed(8);
infltargstarbar = param_fixed(9);
c2star = param_fixed(10); 
c4star = param_fixed(11);

delta = ((1-theta)*(1-beta*theta))/theta;
kappa0 = gamma*(sigma-1);
kappa = sigma+phi-kappa0;
lambda = delta*kappa;
sigma0 = sigma-kappa0;
deltastar = ((1-thetastar)*(1-betastar*thetastar))/thetastar;
kappa0star = (1-gamma)*(sigmastar-1);
kappastar = sigmastar+phistar-kappa0star;
lambdastar = deltastar*kappastar;
sigma0star = sigmastar-kappa0star;

save parameterfiletemp beta sigma phi theta gamma kappa0 kappa sigma0 delta lambda ...
    rhou_infl rhoa rhor rhou_r phipi phiy rhoinfltarg infltargbar c2 c4 ...
    betastar sigmastar phistar thetastar kappa0star kappastar sigma0star deltastar lambdastar ...
    rhou_inflstar rhoastar rhorstar rhou_rstar phipistar phiystar rhoinfltargstar infltargstarbar c2star c4star ...
    std_infl std_a std_r std_infltarg ...
    std_inflstar std_astar std_rstar std_infltargstar;

%% Solve and compute theoretical moments

% 1. Run Dynare

try
    dynare NK_CGG02_impinf4.mod;
catch
    obj=1000000000000;
    return;
end

if impinf == 1

    dr = oo_.dr; % directory file

    % varobs = {'r';'rstar'}; % observed variables, as declared in the mod file (varobs in Dynare)
    % varobs = {'infl';'r';'inflstar';'rstar'}; % observed variables, as declared in the mod file (varobs in Dynare)
    varobs = {'infl';'r';'infltarg';'inflstar';'rstar';'infltargstar'}; % observed variables, as declared in the mod file (varobs in Dynare)
    % varobs = {'rr';'infl';'r';'rrstar';'inflstar';'rstar'}; % observed variables, as declared in the mod file (varobs in Dynare)
    % varobs = {'rr';'infl';'r';'infltarg';'rrstar';'inflstar';'rstar';'infltargstar'}; % observed variables, as declared in the mod file (varobs in Dynare)
    % varobs = {'ytilde';'rr';'infl';'r';'ytildestar';'rrstar';'inflstar';'rstar'}; % observed variables, as declared in the mod file (varobs in Dynare)
    OBS = [];
    for i = 1:rows(varobs)
        OBS = [OBS find(strcmp(deblank(varobs(i,:)),cellstr(M_.endo_names)))];
    end
    NOBS = length(OBS); % number of observed variables

    % Note: Dynare processes the model in the form
    %
    % A0*E_t[y(t+1)]+A1*y(t) = A2*y(t-1)+psi*eps(t)
    %
    % which needs to be transformed into the form used by Pearlman et al. 
    % 
    % [eps(t+1)' s(t)' x(t)' E_t[x(t+1)]']' = G*[eps(t)' s(t-1)' x(t-1)' x(t)]'+impact*eps(t)
    %
    % to obtain the solution under partial information. This is done through
    % Sim's Gensys package. The resulting system satisfies
    %
    % nmat*[E_t[s(t)]' E_t[x(t)]']'+E_t[x(t+1)] = 0 and y(t) = [TT1 TT2]*[s(t)' x(t)']'
    % 
    % which are used to generate irfs.

    G = dr.PI_ghx;
    impact = dr.PI_ghu;
    nmat = dr.PI_nmat; 
    NX = M_.exo_nbr; % number of exogenous shock variables (varexo in Dynare)
    NY = M_.endo_nbr; % number of endogenous variables (var in Dynare)
    ss = size(G,1); % dimension of the augmented state space system
    pd = ss-size(nmat,1); % number of predetermined variables in the augmented state space system
    FL_RANK = dr.PI_FL_RANK; % number of forward-looking variables in the augmented state space system

    VV = M_.H; % variance-covariance of observation errors (this is zero for what we do) 
    SDX = M_.Sigma_e^0.5; % standard deviation of exogenous shock variables (varexo in Dynare)
    MM = impact*SDX; 
    MM1 = MM(1:ss-FL_RANK,:);
    U11 = MM1*MM1'; % variance-covariance of shocks to predetermined variables
    U22 = 0; % assume no shocks to expectations of future variables

    LL = sparse(1:NOBS,OBS,ones(NOBS,1),NY,NY); % selection matrix for observable variables
    L1 = LL*dr.PI_TT1; % mapping from s(t) to observables
    L2 = LL*dr.PI_TT2; % mapping from x(t) to observables

    Gs = G(NX+1:ss-2*FL_RANK,:); % coefficients for s(t) in G
    KK1 = L1*Gs;
    K1 = KK1(:,1:ss-FL_RANK); % mapping from eps(t), s(t-1), and x(t-1) to observables
    K2 = KK1(:,ss-FL_RANK+1:ss)+L2; % mapping from x(t) to observables

    % 2. Solve

    % Note: Refer to page 5 of Joe Pearlman's manual for the explanation

    % Relevant matrices
    A11 = G(1:pd,1:pd);
    A22 = G(pd+1:end,pd+1:end);
    A12 = G(1:pd,pd+1:end);
    A21 = G(pd+1:end,1:pd);
    BB = A12*inv(A22);
    FF = K2*inv(A22);
    QQ = BB*U22*BB'+U11;
    UFT = U22*FF';
    CCCC = A11-A12*nmat; % F in the manual 
    AA = A11-BB*A21; % A in the manual 
    EE = K1-K2*nmat; % E in the manual 
    DD = K1-FF*A21; % H in the manual
    RR = FF*UFT+VV; % This is zero for what we do
    if ~any(RR)
        % Adding measurement errors facilitates computation for the solver we use
        RR = eye(size(RR,1))*1.0e-6;
    end
    SS = BB*UFT;

    % Solving the Riccati equation
    AQDS = AA*QQ*DD'+SS;
    DQDR = DD*QQ*DD'+RR;
    I_DQDR = inv(DQDR);
    AQDQ = AQDS*I_DQDR;
    ff = AA-AQDQ*DD;
    hh = AA*QQ*AA'-AQDQ*AQDS';
    rr = DD*QQ*DD'+RR;
    ZSIG0 = disc_riccati_fast(ff,DD,rr,hh); % solver 
    PP = ZSIG0+QQ; % solution (P in the manual)

    % Augmented solution system (consisting of the solutions for z and ztilde in the manual)
    DPDR = DD*PP*DD'+RR;
    I_DPDR = inv(DPDR);
    PDIDPDRD = PP*DD'*I_DPDR*DD;
    % GG = [CCCC (AA-CCCC)*(eye(ss-FL_RANK)-PDIDPDRD); zeros(ss-FL_RANK) AA*(eye(ss-FL_RANK)-PDIDPDRD)];
    % imp = [impact(1:ss-FL_RANK,:); impact(1:ss-FL_RANK,:)];

    % 3. Compute theoretical moments

    % Covariance
    MSIG = disclyap_fast(CCCC,CCCC*PDIDPDRD*PP*CCCC',options_.lyapunov_doubling_tol);
    COV_P = [PP PP; PP PP+MSIG]; % P0 in the manual
    VV = [dr.PI_TT1 dr.PI_TT2];
    nn = size(VV,1);
    COV_OMEGA = COV_P(end-nn+1:end,end-nn+1:end);
    COV_YR0 = VV*COV_OMEGA*VV';
    diagCovYR0 = diag(COV_YR0);
    targvarlist = {'rstar';'r';'ystar';'y';'inflstar';'infl'};
    targvar = [];
    for i = 1:rows(targvarlist)
        targvar = [targvar find(strcmp(deblank(targvarlist(i,:)),cellstr(M_.endo_names)))];
    end
    z = [sqrt(diagCovYR0(targvar)) diagCovYR0(targvar)];
    % labels = deblank(M_.endo_names(targvar,:));
    % title = 'THEORETICAL MOMENTS';
    % headers = char('VARIABLE','STD. DEV.','VARIANCE');
    % dyntable(options_,title,headers,labels,z,size(labels,2)+2,16,10);

    % Correlation
    diagSqrtCovYR0 = sqrt(diagCovYR0);
    DELTA = inv(diag(diagSqrtCovYR0));
    COR_Y = DELTA*COV_YR0*DELTA;
    COR_Y_final = COR_Y(targvar,targvar);
    % title = 'MATRIX OF CORRELATION';
    % headers = char('VARIABLE',M_.endo_names(targvar,:));
    % dyntable(options_,title,headers,labels,COR_Y(targvar,targvar),size(labels,2)+2,8,4);

    % Serial correlation
    ar = 1; % ar = 2 is up to second order, ar = 3 is up to third order, and so on
    GAM = [AA*(eye(ss-FL_RANK)-PDIDPDRD) zeros(ss-FL_RANK); (AA-CCCC)*(eye(ss-FL_RANK)-PDIDPDRD) CCCC];
    COV_YRk = zeros(nn,ar);
    AutoCOR_YRk = zeros(nn,ar);
    for k = 1:ar
        COV_P = GAM*COV_P;
        COV_OMEGA = COV_P(end-nn+1:end,end-nn+1:end);
        COV_YRk = VV*COV_OMEGA*VV';
        AutoCOR_YRk(:,k) = diag(COV_YRk)./diagCovYR0;
    %     title = 'COEFFICIENTS OF AUTOCORRELATION';
    %     headers = char('VARIABLE',['ORDER = ' int2str([1:ar]')]);
    %     dyntable(options_,title,headers,labels,AutoCOR_YRk(targvar,:),size(labels,2)+2,8,4);
    end
    AutoCOR_YRk_final = AutoCOR_YRk(targvar,:);

    modelmoments = zeros(27,1);
    modelmoments(1:6,1) = z(:,1);
    modelmoments(7,1) = COR_Y_final(1,2);
    modelmoments(8,1) = COR_Y_final(1,3);
    modelmoments(9,1) = COR_Y_final(1,4);
    modelmoments(10,1) = COR_Y_final(1,5);
    modelmoments(11,1) = COR_Y_final(1,6);
    modelmoments(12,1) = COR_Y_final(2,3);
    modelmoments(13,1) = COR_Y_final(2,4);
    modelmoments(14,1) = COR_Y_final(2,5);
    modelmoments(15,1) = COR_Y_final(2,6);
    modelmoments(16,1) = COR_Y_final(3,4);
    modelmoments(17,1) = COR_Y_final(3,5);
    modelmoments(18,1) = COR_Y_final(3,6);
    modelmoments(19,1) = COR_Y_final(4,5);
    modelmoments(20,1) = COR_Y_final(4,6);
    modelmoments(21,1) = COR_Y_final(5,6);
    modelmoments(22:27,1) = AutoCOR_YRk_final;
    
else
    
    targvarlist = {'rstar';'r';'ystar';'y';'inflstar';'infl'};
    targvar = [];
    for i = 1:rows(targvarlist)
        targvar = [targvar find(strcmp(deblank(targvarlist(i,:)),cellstr(M_.endo_names)))];
    end
    
    % Covariance
    COV_YR0 = oo_.var;
    diagCovYR0 = diag(COV_YR0);
    z = [sqrt(diagCovYR0(targvar)) diagCovYR0(targvar)];
    
    % Correlation
    diagSqrtCovYR0 = sqrt(diagCovYR0);
    DELTA = inv(diag(diagSqrtCovYR0));
    COR_Y = DELTA*COV_YR0*DELTA;
    COR_Y_final = COR_Y(targvar,targvar);
    
    % Serial correlation
    ar = 1; % ar = 2 is up to second order, ar = 3 is up to third order, and so on
    AutoCOR_YRkraw = cell2mat(oo_.autocorr(:,1:ar));
    nn = size(AutoCOR_YRkraw,1);
    AutoCOR_YRk = zeros(nn,ar);
    for k = 1:ar
        AutoCOR_YRk(:,k) = diag(AutoCOR_YRkraw(1:nn,(k-1)*nn+1:k*nn));
    end
    AutoCOR_YRk_final = AutoCOR_YRk(targvar,:);
    
    modelmoments = zeros(27,1);
    modelmoments(1:6,1) = z(:,1);
    modelmoments(7,1) = COR_Y_final(1,2);
    modelmoments(8,1) = COR_Y_final(1,3);
    modelmoments(9,1) = COR_Y_final(1,4);
    modelmoments(10,1) = COR_Y_final(1,5);
    modelmoments(11,1) = COR_Y_final(1,6);
    modelmoments(12,1) = COR_Y_final(2,3);
    modelmoments(13,1) = COR_Y_final(2,4);
    modelmoments(14,1) = COR_Y_final(2,5);
    modelmoments(15,1) = COR_Y_final(2,6);
    modelmoments(16,1) = COR_Y_final(3,4);
    modelmoments(17,1) = COR_Y_final(3,5);
    modelmoments(18,1) = COR_Y_final(3,6);
    modelmoments(19,1) = COR_Y_final(4,5);
    modelmoments(20,1) = COR_Y_final(4,6);
    modelmoments(21,1) = COR_Y_final(5,6);
    modelmoments(22:27,1) = AutoCOR_YRk_final;
    
end

%% Objective function

obj=((modelmoments-actualmoments)./actualmoments)'*weightingmat*((modelmoments-actualmoments)./actualmoments);

