% A replication file for "Monetary Policy Surprises and Exchange Rate
% Behavior" by Gurkaynak, Kara, Kisacikoglu and Lee.

% This m file plots yield curve and exchange rate figures in the paper.

clear;
clc;

irfplot=20; % number of periods 

%% 1. Figure 6 

load datafull.mat;
figure;
subplot(4,3,1)
plot((1:6)',10000*datafull1(1:6,1),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('EA yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA inf shock','FontSize',20);

subplot(4,3,2)
plot((1:6)',10000*datafull1(7:12,1),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('US yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,3)
plot((1:irfplot),100*datafull2(1,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
title('USD/EUR (in %)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,4)
plot((1:6)',10000*datafull1(1:6,2),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA productivity shock','FontSize',20);

subplot(4,3,5)
plot((1:6)',10000*datafull1(7:12,2),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,6)
plot((1:irfplot),100*datafull2(2,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,7)
plot((1:6)',10000*datafull1(1:6,3),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA int rate shock','FontSize',20);

subplot(4,3,8)
plot((1:6)',10000*datafull1(7:12,3),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,9)
plot((1:irfplot),100*datafull2(3,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,10)
plot((1:6)',10000*datafull1(1:6,4),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA inf targ shock','FontSize',20,'Location','SouthWest');

subplot(4,3,11)
plot((1:6)',10000*datafull1(7:12,4),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,12)
plot((1:irfplot),100*datafull2(4,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

figure;
subplot(4,3,1)
plot((1:6)',10000*datafull1(1:6,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('EA (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US inf shock','FontSize',20,'Location','SouthEast');

subplot(4,3,2)
plot((1:6)',10000*datafull1(7:12,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('US (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,3)
plot((1:irfplot),100*datafull2(5,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
title('USD/EUR (in %)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,4)
plot((1:6)',10000*datafull1(1:6,6),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US productivity shock','FontSize',20,'Location','SouthEast');

subplot(4,3,5)
plot((1:6)',10000*datafull1(7:12,6),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,6)
plot((1:irfplot),100*datafull2(6,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,7)
plot((1:6)',10000*datafull1(1:6,7),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US int rate shock','FontSize',20,'Location','SouthEast');

subplot(4,3,8)
plot((1:6)',10000*datafull1(7:12,7),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,9)
plot((1:irfplot),100*datafull2(7,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,10)
plot((1:6)',10000*datafull1(1:6,8),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US inf targ shock','FontSize',20);

subplot(4,3,11)
plot((1:6)',10000*datafull1(7:12,8),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,12)
plot((1:irfplot),100*datafull2(8,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

%% 2. Figure 9

load data4.mat;
figure;
subplot(4,3,1)
plot((1:6)',10000*data41(1:6,1),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('EA yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA inf shock','FontSize',20)

subplot(4,3,2)
plot((1:6)',10000*data41(7:12,1),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('US yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,3)
plot((1:irfplot),100*data42(1,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
title('USD/EUR (in %)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,4)
plot((1:6)',10000*data41(1:6,2),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA productivity shock','FontSize',20)

subplot(4,3,5)
plot((1:6)',10000*data41(7:12,2),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,6)
plot((1:irfplot),100*data42(2,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,7)
plot((1:6)',10000*data41(1:6,3),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA int rate shock','FontSize',20)

subplot(4,3,8)
plot((1:6)',10000*data41(7:12,3),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,9)
plot((1:irfplot),100*data42(3,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,10)
plot((1:6)',10000*data41(1:6,4),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('EA inf targ shock','FontSize',20,'Location','SouthEast')

subplot(4,3,11)
plot((1:6)',10000*data41(7:12,4),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,12)
plot((1:irfplot),100*data42(4,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

figure;
subplot(4,3,1)
plot((1:6)',10000*data41(1:6,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('EA (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US inf shock','FontSize',20,'Location','SouthEast');

subplot(4,3,2)
plot((1:6)',10000*data41(7:12,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('US (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,3)
plot((1:irfplot),100*data42(5,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
title('USD/EUR (in %)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,4)
plot((1:6)',10000*data41(1:6,6),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US productivity shock','FontSize',20,'Location','SouthEast');

subplot(4,3,5)
plot((1:6)',10000*data41(7:12,6),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,6)
plot((1:irfplot),100*data42(6,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,7)
plot((1:6)',10000*data41(1:6,7),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US int rate shock','FontSize',20,'Location','NorthWest');

subplot(4,3,8)
plot((1:6)',10000*data41(7:12,7),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,9)
plot((1:irfplot),100*data42(7,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,10)
plot((1:6)',10000*data41(1:6,8),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US inf targ shock','FontSize',20,'Location','SouthWest');

subplot(4,3,11)
plot((1:6)',10000*data41(7:12,8),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,12)
plot((1:irfplot),100*data42(8,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

%% 3. Bottom row of Figure 10

load data4twoshocks.mat;
figure;
subplot(4,3,1)
plot((1:6)',10000*data4twoshocks1(1:6,1),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('EA yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,2)
plot((1:6)',10000*data4twoshocks1(7:12,1),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('US yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,3)
plot((1:irfplot),100*data4twoshocks2(1,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
title('USD/EUR (in %)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

%% 4. Figure 11

load data3.mat;
load data4.mat;
load data5.mat;
figure;
subplot(4,3,1)
plot((1:6)',10000*data31(1:6,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('EA yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US inf shock','FontSize',20,'Location','SouthEast');

subplot(4,3,2)
plot((1:6)',10000*data31(7:12,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
title('US yields (in bps)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,3)
plot((1:irfplot),100*data32(5,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
title('USD/EUR (in %)','FontSize',25);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,4)
plot((1:6)',10000*data41(1:6,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US inf shock','FontSize',20,'Location','SouthEast');

subplot(4,3,5)
plot((1:6)',10000*data41(7:12,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,6)
plot((1:irfplot),100*data42(5,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,7)
plot((1:6)',10000*data51(1:6,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
legend('US inf shock','FontSize',20,'Location','SouthEast');

subplot(4,3,8)
plot((1:6)',10000*data51(7:12,5),'b-','LineWidth',2);
hold on;
plot((1:6)',0*ones(6,1),'r-','LineWidth',2);
xlim([1 6]);
xticks((1:6));
xticklabels({'3','6','12','24','60','120'});
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);

subplot(4,3,9)
plot((1:irfplot),100*data52(5,1:irfplot),'b-','LineWidth',2);
hold on;
plot((1:irfplot),0*ones(1,irfplot),'r-','LineWidth',2);
xlim([1 irfplot]);
xticks([5 10 15 20]);
x12 = get(gca,'XAxis');
set(x12,'FontSize',22);
y12 = get(gca,'YAxis');
set(y12,'FontSize',22);
