*********************************************************************************
* Event study results for "Monetary Policy Surprises and Exchange Rate Behavior"*
* Refet S. Gurkaynak, A. Hakan Kara, Burcin Kisacikoglu, Sang Seok Lee			*
* Bilkent University Department of Economics 									*
*																				*
* This do file generates Figures 1, 2, 12 and 13								*
*********************************************************************************

*********************************************************************************
* Event study results for the US												*
*********************************************************************************
clear
use us_eventstudy
* Truncating monetary policy surprises
gen basisdum = 1 if abs(mp1)> 0.02 | abs(ed4)>0.02  
replace mp1 = mp1*100
gen euro1 = euro*10

* Time series of Kuttner surprise and exchange rate responses pre and post crisis.
graph bar (asis) mp1 euro1 if ddate<td(01Jan2008) & euro1~=. & mp1 ~=., over(ddate, label(nolabel))  legend(label(1 "Target Surprise") label(2 "USD/EUR")) title("US  1994-2007")
graph save target_vs_euro_precrisis, replace
graph bar (asis) mp1 euro1 if ddate>td(31Dec2007) & euro1~=. & mp1 ~=., over(ddate, label(nolabel))  legend(label(1 "Target Surprise") label(2 "USD/EUR")) title("US 2008-2018")
graph save target_vs_euro_crisis, replace 
graph combine target_vs_euro_precrisis.gph target_vs_euro_crisis.gph 
graph save target_vs_euro_subsample_combined

*********************************************************************************
* Construct path surprises. We regress change in fourth Eurodollar futures 		*	
* around monetary policy announcements on the Kuttner surprise. The residual	*	
* of this regression is defined as the path surprise. 							*	
*********************************************************************************
reg ed4 mp1 if basisdum == 1 & abs(euro)>0.2
predict path if basisdum == 1 & abs(euro)>0.2, residuals
gen path1 = path*100

* Time series of Path surprise and exchange rate responses pre and post crisis.
graph bar (asis) path1 euro1 if ddate<td(01Jan2008) & euro1~=. & path1 ~=., over(ddate, label(nolabel)) legend(label(1 "Path Surprise") label(2 "USD/EUR")) title("US 1994-2007")
graph save path_vs_euro_precrisis, replace
graph bar (asis) path1 euro1 if ddate>td(31Dec2007) & euro1~=. & path1 ~=., over(ddate, label(nolabel)) legend(label(1 "Path Surprise") label(2 "USD/EUR")) title("US 2008-2018")
graph save path_vs_euro_crisis, replace
graph combine path_vs_euro_precrisis.gph path_vs_euro_crisis.gph
graph save path_vs_euro_subsample_combined

*********************************************************************************
* Generate 6 different dummy variables including the ones where mp1 == 0 		*
* Information days are indicated by the following dummies: kuttner_dummy1, 		*
* kuttner_dummy2, kuttner_dummy3, kuttner_dummy6 								*
* Note: variable euro is dollar per euro										*
*********************************************************************************

gen kuttner_dummy1 = 1 if mp1 == 0 & euro >0 & basisdum == 1 & abs(euro)>0.2 
gen kuttner_dummy2 = 1 if mp1 == 0 & euro <0 & basisdum == 1 & abs(euro)>0.2
gen kuttner_dummy3 = 1 if mp1 >  0 & euro >0 & basisdum == 1 & abs(euro)>0.2 
gen kuttner_dummy4 = 1 if mp1 >  0 & euro <0 & basisdum == 1 & abs(euro)>0.2
gen kuttner_dummy5 = 1 if mp1 <  0 & euro >0 & basisdum == 1 & abs(euro)>0.2
gen kuttner_dummy6 = 1 if mp1 <  0 & euro <0 & basisdum == 1 & abs(euro)>0.2 

*********************************************************************************
* Generate wrong and correct sign days with the kuttner_dummy 					*
*********************************************************************************
gen wrongdum = 1 if kuttner_dummy1 == 1 | kuttner_dummy2 == 1 | kuttner_dummy3 == 1 | kuttner_dummy6 == 1
gen correctdum = 1 if kuttner_dummy4 ==  1 | kuttner_dummy5 == 1

*********************************************************************************
* Do a scatter plot of the wrong sign and correct sign policy days with a 		*
* regression line												 				*
*********************************************************************************
twoway (scatter euro mp1 if wrongdum == 1  , yline(0) xline(0) xtitle("Target Surprise (US)") ytitle("USD/EUR") xlabel(-50(10)50) mcolor("red") msize(small) legend(label(1 "Information Days")label(2 "Non-Information Days") label(3 "Regression Line"))) ///
	   (scatter euro mp1 if kuttner_dummy4 ==  1 | kuttner_dummy5 == 1, yline(0) xline(0) xtitle("Target Surprise (US)") ytitle("USD/EUR") xlabel(-50(10)50) mcolor("green") msize(small) ) ///
	   (lfit euro mp1, lpattern (_) lcolor(black))
	   
graph save kuttner_vs_euro.gph, replace
*********************************************************************************
* Pin down policy days with wrong sign according to Kuttner surprise but correct* 
* sign according to the path surprise	   										*
*********************************************************************************
gen wrong_to_kuttner_correct_to_path = 1 if kuttner_dummy1 == 1 & path < 0 | kuttner_dummy2 ==1 & path>0 | kuttner_dummy3 == 1 & path < 0 | kuttner_dummy6 == 1 & path >0 

*********************************************************************************
* Pin down policy days with wrong sign according to Kuttner surprises and path	*
* surprises.																	*
*********************************************************************************
gen wrong_to_kuttner_wrong_to_path = 1 if kuttner_dummy1 == 1 & path >0 | kuttner_dummy2 ==1 & path<0 | kuttner_dummy3 == 1 & path > 0 | kuttner_dummy6 == 1 & path <0

*********************************************************************************
* Do a scatter plot 															*
*********************************************************************************
twoway (scatter euro mp1 if wrong_to_kuttner_wrong_to_path == 1 , yline(0) xline(0) xtitle("Target Surprise (US)") ytitle("USD/EUR") xlabel(-10(5)10) mcolor("red") msize(small) legend(label(1 "Wrong Sign (Target and Path)") label(2 "Correct Sign (Path)"))) ///
	   (scatter euro mp1 if wrong_to_kuttner_correct_to_path == 1, yline(0) xline(0) xlabel(-10(5)10) mcolor("green") msize(small) )

graph save path_vs_euro.gph, replace
	   

********************************************************************************
********************************************************************************
********************************************************************************

********************************************************************************
* Event study results for the Euro Area										   *
********************************************************************************
clear
use ea_eventstudy
* Truncating monetary policy surprises 
gen basisdum = 1 if abs(ois_1m)> 0.02 | abs(ois_1y)>0.02 

*********************************************************************************
* Construct path surprises. We regress change in one-year OIS interest rates 	*	
* around monetary policy announcements on the one-month OIS. The residual		*	
* of this regression is defined as the path surprise. 							*	
*********************************************************************************
reg ois_1y ois_1m if basisdum == 1 & abs(euro)>0.2
predict path if basisdum == 1 & abs(euro)>0.2, residuals

* Scaling exchange response so that relationship is more visible in the graphs below
gen euro1 = euro*10 

* Time series of Kuttner surprise and exchange rate response pre and post crisis
graph bar (asis) ois_1m euro1 if ddate<td(01Jan2008) & euro1~=. & ois_1m ~=., over(ddate, label(nolabel)) legend(label(1 "Target Surprise") label(2 "USD/EUR")) title("Euro Area 1999-2007")
graph save target_vs_euro_precrisis_ea, replace 
graph bar (asis) ois_1m euro1 if ddate>td(31Dec2007) & euro1~=. & ois_1m ~=., over(ddate, label(nolabel)) legend(label(1 "Target Surprise") label(2 "USD/EUR")) title("Euro Area 2008-2018")
graph save target_vs_euro_crisis_ea, replace
graph combine target_vs_euro_precrisis_ea.gph target_vs_euro_crisis_ea.gph
graph save target_vs_euro_subsample_ea_combined, replace

* Time series of Path surprise and exchange rate response pre and post crisis
graph bar (asis) path euro1 if ddate<td(01Jan2008) & euro1~=. & path ~=., over(ddate, label(nolabel))  legend(label(1 "Path Surprise") label(2 "USD/EUR")) title("Euro Area 1999-2007")
graph save path_vs_euro_precrisis_ea, replace
graph bar (asis) path euro1 if ddate>td(31Dec2007) & euro1~=. & path ~=., over(ddate, label(nolabel))  legend(label(1 "Path Surprise") label(2 "USD/EUR")) title("Euro Area 2008-2018")
graph save path_vs_euro_crisis_ea, replace
graph combine path_vs_euro_precrisis_ea.gph path_vs_euro_crisis_ea.gph
graph save path_vs_euro_subsample_ea_combined, replace

*********************************************************************************
* Generate 6 different dummy variables including the ones where ois_1m == 0, 	*
* Information days are indicated by the following dummies: kuttner_dummy1, 		*
* kuttner_dummy2, kuttner_dummy4, kuttner_dummy5 								*
* Note: variable euro is dollar per euro										*
*********************************************************************************
gen kuttner_dummy1 = 1 if ois_1m == 0 & euro >0 & basisdum == 1 & abs(euro)>0.2 
gen kuttner_dummy2 = 1 if ois_1m == 0 & euro <0 & basisdum == 1 & abs(euro)>0.2
gen kuttner_dummy3 = 1 if ois_1m >  0 & euro >0 & basisdum == 1 & abs(euro)>0.2 
gen kuttner_dummy4 = 1 if ois_1m >  0 & euro <0 & basisdum == 1 & abs(euro)>0.2
gen kuttner_dummy5 = 1 if ois_1m <  0 & euro >0 & basisdum == 1 & abs(euro)>0.2
gen kuttner_dummy6 = 1 if ois_1m <  0 & euro <0 & basisdum == 1 & abs(euro)>0.2

*********************************************************************************
* Generate wrong and correct sign days with the kuttner_dummy 					*
*********************************************************************************
gen wrongdum = 1 if  kuttner_dummy1 == 1 | kuttner_dummy2 == 1 | kuttner_dummy4 == 1 | kuttner_dummy5 == 1 
gen correctdum = 1 if kuttner_dummy3 ==  1 | kuttner_dummy6 == 1

*********************************************************************************
* Do a scatter plot of the wrong sign and correct sign policy days with a		* 
* regression line.																*
*********************************************************************************
twoway (scatter euro ois_1m if wrongdum == 1, yline(0) xline(0) xtitle("Target Surprise (EA)") ytitle("USD/EUR") xlabel(-40(10)40) mcolor("red") msize(small) legend(label(1 "Information Days") label(2 "Non-Information Days") label(3 "Regression Line"))) ///
	   (scatter euro ois_1m if kuttner_dummy3 ==  1 | kuttner_dummy6 == 1, yline(0) xline(0) xtitle("Target Surprise (EA)") ytitle("USD/EUR") xlabel(-40(10)40) mcolor("green") msize(small)) ///
	   (lfit euro ois_1m, lpattern(_) lcolor(black))
	   
graph save kuttner_vs_euro_ea, replace
	   
*********************************************************************************
* Pin down policy days with wrong sign according to Kuttner surprise but correct* 
* sign according to the path surprise	   										*
*********************************************************************************	   
gen wrong_to_kuttner_correct_to_path = 1 if kuttner_dummy1 == 1 & path >0 | kuttner_dummy2 == 1 & path <0 | kuttner_dummy4 == 1 & path < 0 | kuttner_dummy5 == 1 & path>0 

*********************************************************************************
* Pin down policy days with wrong sign according to Kuttner surprises and path	*
* surprises.																	*
*********************************************************************************
gen wrong_to_kuttner_wrong_to_path = 1 if kuttner_dummy1 == 1 & path <0 | kuttner_dummy2 ==1 & path>0 | kuttner_dummy4 == 1 & path >0 | kuttner_dummy5 == 1 & path <0

*********************************************************************************
* Do a scatter plot 															*
*********************************************************************************
twoway (scatter euro ois_1m if wrong_to_kuttner_wrong_to_path == 1 , yline(0) xline(0)  xtitle("Target Surprise (EA)") ytitle("USD/EUR") xlabel(-40(10)40) mcolor("red") msize(small) legend(label(1 "Wrong Sign (Target and Path)") label(2 "Correct Sign (Path)"))) ///
	   (scatter euro ois_1m if wrong_to_kuttner_correct_to_path == 1, yline(0) xline(0) xtitle("Target Surprise (EA)") ytitle("USD/EUR") xlabel(-40(10)40) mcolor("green") msize(small))

graph save kuttner_path_vs_euro_ea, replace

	   